(autoload 'folding-bind-default-mouse           "folding" "" t)
(autoload 'folding-bind-default-keys            "folding" "" t)
(autoload 'folding-bind-backward-compatible-keys "folding" "" t)
(autoload 'folding-bind-outline-compatible-keys "folding" "" t)
(autoload 'folding-bind-foldout-compatible-keys "folding" "" t)
(autoload 'folding-easy-menu-define             "folding" "" t)
(autoload 'folding-install                      "folding" "" t)
(autoload 'folding-uninstall                    "folding" "" t)
(autoload 'folding-get-mode-marks               "folding" "" t);;defsubst
(autoload 'folding-region-open-close            "folding" "" t)
(autoload 'fold-marks-kill                      "folding" "" t)
(autoload 'folding-hide-current-subtree         "folding" "" t)
(autoload 'folding-show-current-subtree         "folding" "" t)
(autoload 'folding-display-name                 "folding" "" t)
(autoload 'folding-mouse-call-original          "folding" "" t)
(autoload 'folding-mouse-context-sensitive      "folding" "" t)
(autoload 'folding-mouse-move                   "folding" "" t)
(autoload 'folding-mouse-pick-move              "folding" "" t)
(autoload 'folding-mode-add-find-file-hook      "folding" "" t)
(autoload 'folding-mode                         "folding" "" t)
(autoload 'folding-next-visible-heading         "folding" "" t)
(autoload 'folding-previous-visible-heading     "folding" "" t)
(autoload 'folding-pick-move                    "folding" "" t)
(autoload 'folding-context-next-action          "folding" "" t)
(autoload 'folding-skip-ellipsis-backward       "folding" "" t)
(autoload 'folding-shift-in                     "folding" "" t)
(autoload 'folding-shift-out                    "folding" "" t)
(autoload 'folding-show-current-entry           "folding" "" t)
(autoload 'folding-toggle-enter-exit            "folding" "" t)
(autoload 'folding-toggle-show-hide             "folding" "" t)
(autoload 'folding-hide-current-entry           "folding" "" t)
(autoload 'folding-show-all                     "folding" "" t)
(autoload 'folding-goto-line                    "folding" "" t)
(autoload 'folding-fold-region                  "folding" "" t)
(autoload 'folding-tidy-inside                  "folding" "" t)
(autoload 'folding-whole-buffer                 "folding" "" t)
(autoload 'folding-open-buffer                  "folding" "" t)
(autoload 'folding-convert-buffer-for-printing  "folding" "" t)
(autoload 'folding-add-to-marks-list            "folding" "" t)
(autoload 'folding-eval-current-buffer-open-folds "folding" "" t)
(autoload 'folding-isearch-edit-string          "folding" "" t)
(autoload 'folding-isearch-ring-advance         "folding" "" t)
(autoload 'folding-isearch-ring-retreat         "folding" "" t)
(autoload 'folding-isearch-complete             "folding" "" t)
(autoload 'folding-isearch-forward-exit-minibuffer "folding" "" t)
(autoload 'folding-isearch-reverse-exit-minibuffer "folding" "" t)
(autoload 'folding-isearch-nonincremental-exit-minibuffer "folding" "" t)
(autoload 'folding-insert-advertise-folding-mode "folding" "" t)
(autoload 'folding-comment-fold                 "folding" "" t)
(autoload 'folding-convert-to-major-folds       "folding" "" t)
(autoload 'folding-all-comment-blocks-in-region "folding" "" t)
(provide 'folding-mode-epackage-autoloads)
